
import sys
import maya.api.OpenMaya as OpenMaya
import maya.api.OpenMayaUI as OpenMayaUI
import maya.api.OpenMayaRender as OpenMayaRender
 
def maya_useNewAPI():
    pass

class MayaSphere(OpenMayaUI.MPxLocatorNode):
    NAME = "MayaSphere"
    ID = OpenMaya.MTypeId(100002)
    RADIUS = None

    @staticmethod
    def creator():
        return MayaSphere()

    @staticmethod
    def initialize():
        nAttr = OpenMaya.MFnNumericAttribute()
        MayaSphere.RADIUS = nAttr.create ("radius", "r", OpenMaya.MFnNumericData.kFloat, 1.0)
        OpenMaya.MPxNode.addAttribute(MayaSphere.RADIUS)

    def __init__(self):
        OpenMayaUI.MPxLocatorNode.__init__(self)

    def cOpenMayapute(self, plug, data):
        return None

    def isBounded(self):
        return True

    def boundingBox(self):
        thisNode = self.thisMObject()
        plug = OpenMaya.MPlug(thisNode, MayaSphere.RADIUS)
        radius = plug.asFloat()
        corner1 = OpenMaya.MPoint(-radius, -radius, -radius)
        corner2 = OpenMaya.MPoint(radius, radius, radius)
        return OpenMaya.MBoundingBox(corner1, corner2)

def initializePlugin(obj):
    plugin = OpenMaya.MFnPlugin(obj)
    try:
        plugin.registerNode(MayaSphere.NAME, MayaSphere.ID, MayaSphere.creator, MayaSphere.initialize, OpenMaya.MPxNode.kLocatorNode)
    except:
        sys.stderr.write("Failed to register node: %s" % MayaSphere.NAME)
 
def uninitializePlugin(obj):
    plugin = OpenMaya.MFnPlugin(obj)
    try:
        plugin.deregisterNode(MayaSphere.ID)
    except:
        sys.stderr.write("Failed to deregister node: %s" % MayaSphere.NAME)

