
#include "ri.h"
#include "prmanapi.h"
#include "RixPredefinedStrings.hpp"

struct Params
{
    Params(RtInt n, RtToken const toks[], RtPointer const vals[]);
    float radius;
    float displacementbound;
    RtUString bxdf;
    RtUString light;
    RtUString displace;
};

Params::Params(RtInt n, RtToken const toks[], RtPointer const vals[]) :
    radius(1),
    displacementbound(0),
    bxdf(US_NULL),
    light(US_NULL),
    displace(US_NULL)
{
    while (--n >= 0)
    {
        if (std::strstr(toks[n], "radius"))
        {
            radius = *(float*)vals[n];
        }
        else if (std::strstr(toks[n], "displacementbound"))
        {
            displacementbound = *(float*)vals[n];
        }
        else if (std::strstr(toks[n], "bxdf"))
        {
            bxdf = *(RtUString*)vals[n];
        }
        else if (std::strstr(toks[n], "light"))
        {
            light = *(RtUString*)vals[n];
        }
        else if (std::strstr(toks[n], "displace"))
        {
            displace = *(RtUString*)vals[n];
        }
    }
}

extern "C" PRMANEXPORT RtVoid
Bound(RtInt n, RtToken const toks[], RtPointer const vals[], RtBound result[2])
{
    Params const params(n, toks, vals);
    float const radius = params.radius + params.displacementbound;
    result[0][0] = result[1][0] = -radius;
    result[0][1] = result[1][1] =  radius;
    result[0][2] = result[1][2] = -radius;
    result[0][3] = result[1][3] =  radius;
    result[0][4] = result[1][4] = -radius;
    result[0][5] = result[1][5] =  radius;
}

extern "C" PRMANEXPORT RtVoid
Subdivide2(RtContextHandle ctx, RtFloat detail,
          RtInt n, RtToken const toks[], RtPointer const vals[])
{
    // The Bxdf/Displace "__materialid" corresponds to the shading group name in RfM
    static RtToken const k_type = Rix::k_empty.CStr(); // Should be empty
    static RtToken const k_handle = Rix::k_empty.CStr();
    static RtToken const k_materialId = RtUString("string __materialid").CStr();
    static RtToken const k_displacementbound = Rix::k_displacementbound.CStr();
    static RtToken const k_sphere = RtUString("float sphere").CStr();
    Params const params(n, toks, vals);
    if (!params.bxdf.Empty())
    {
        RiBxdf(k_type, k_handle, k_materialId, &params.bxdf, RI_NULL);
    }
    if (!params.light.Empty())
    {
        RiLight(k_type, k_handle, k_materialId, &params.light, RI_NULL);
    }
    if (!params.displace.Empty())
    {
        RiAttribute(k_displacementbound, k_sphere, &params.displacementbound, RI_NULL);
        RiDisplace(k_type, k_handle, k_materialId, &params.displace, RI_NULL);
    }
    RiSphere(params.radius, -params.radius, params.radius, 360.0f, RI_NULL);
}

